<?php
/*
Copyright (c) 200 Ladislav Lencucha <ladislav.lencucha@gmail.com>, all rights
reserved. Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  1.Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  2.Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
  3.The name of the author may not be used to endorse or promote products
    derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */

require_once 'includes/configure.php';

  class SporoPay extends base{
    var $code, $title, $description, $enabled;

////
// !Class constructor -> initialize class variables.
// Sets the class code, description, and status.
    function SporoPay() {
      $this->code = 'SporoPay';
      $this->title = MODULE_PAYMENT_SPOROPAY_TEXT_TITLE;
      $this->description = MODULE_PAYMENT_SPOROPAY_TEXT_DESCRIPTION;
      $this->email_footer = MODULE_PAYMENT_SPOROPAY_TEXT_EMAIL_FOOTER;
      $this->enabled = MODULE_PAYMENT_SPOROPAY_STATUS;
      $this->sort_order = MODULE_PAYMENT_SPOROPAY_SORT_ORDER;

      $this->form_action_url = 'https://ib.slsp.sk/epayment/epayment/epayment.xml';
    }

////
// Create signature
    function make_sign( $value, $pin) {
        // pin is base64 coded, so let's decode it
        $safekey = base64_decode($pin);
        // key is 0..8 + 8..16 + 0..8 bytes
        $key = substr($safekey, 0, 8).substr($safekey, 8, 16).substr($safekey, 0, 8);
        
        // because of PHP/mcrypt module we need to fill some characters...
        $iv = chr(0).chr(0).chr(0).chr(0).chr(0).chr(0).chr(0).chr(0);
        $hash = sha1($value, true).chr(255).chr(255).chr(255).chr(255);
        
        // now encrypt data with 3DES (CBC)
        if (function_exists('mcrypt_module_open')) {         // We have mcrypt 2.4.x
            $td = mcrypt_module_open(MCRYPT_3DES, "", MCRYPT_MODE_CBC, "");
            mcrypt_generic_init($td, $key, $iv);
            $sign = mcrypt_generic ($td, $hash);
            mcrypt_generic_deinit ($td);
        } else {                        // We have 2.2.x only
            $sign = strtoupper(bin2hex(mcrypt_ecb (MCRYPT_3DES, $key, $hash, MCRYPT_ENCRYPT)));
        }
        
        // we need to encode sign with base64 to use it in URL/post 
        $result = base64_encode($sign);
        
        return $result;
    }

////
// Get url
    function get_url() {
        if (ENABLE_SSL_ADMIN == 'true') {
          $link = HTTPS_SERVER . DIR_WS_HTTPS_CATALOG . 'redirect_to_payment.php';
        } else {
          $link = HTTP_SERVER . DIR_WS_CATALOG . 'redirect_to_payment.php';
        }
        
        return $link;
    }
    
////
// Get url parameter
    function get_param() {
    }

////
// Calculate send sign
    function send_sign ($AMT, $variab) {
        return $this->make_sign (str_pad(MODULE_PAYMENT_SPOROPAY_PU_PREDCISLO, 6, '0', STR_PAD_LEFT).';'.str_pad(MODULE_PAYMENT_SPOROPAY_PU_CISLO, 10, '0', STR_PAD_LEFT).';'.str_pad(MODULE_PAYMENT_SPOROPAY_PU_KBANKY, 4, '0', STR_PAD_LEFT).';'.$AMT.';'.MODULE_PAYMENT_SPOROPAY_CUR.';'.str_pad($variab, 10, '0', STR_PAD_LEFT).';'.str_pad(MODULE_PAYMENT_SPOROPAY_SS, 6, '0', STR_PAD_LEFT).';'.$this->get_url().';'.$this->get_param(),
                                 MODULE_PAYMENT_SPOROPAY_PIN);
    }

////
// Calculate receive sign
    function receive_sign ($u_predcislo, $u_cislo, $u_kbanky, $AMT, $variab) {
        $url = zen_href_link(FILENAME_CHECKOUT_PAYMENT, '', 'SSL', true, false);
        return $this->make_sign ($u_predcislo.';'.$u_cislo.';'.$u_kbanky.';'.str_pad(MODULE_PAYMENT_SPOROPAY_PU_PREDCISLO, 6, '0', STR_PAD_LEFT).';'.str_pad(MODULE_PAYMENT_SPOROPAY_PU_CISLO, 10, '0', STR_PAD_LEFT).';'.str_pad(MODULE_PAYMENT_SPOROPAY_PU_KBANKY, 4, '0', STR_PAD_LEFT).';'.$AMT.';'.MODULE_PAYMENT_SPOROPAY_CUR.';'.str_pad($variab, 10, '0', STR_PAD_LEFT).';'.str_pad(MODULE_PAYMENT_SPOROPAY_SS, 10, '0', STR_PAD_LEFT).';'.$this->get_url().';'.$this->get_param().';'.$result.';'.$real.'',
                                 MODULE_PAYMENT_SPOROPAY_PIN);
    }

////
// !Javascript form validation
// Check the user input submited on checkout_payment.php with javascript (client-side).
// Examples: validate credit card number, make sure required fields are filled in
    function javascript_validation() {
// insert code here
    }

////
// !Form fields for user input
// Output any required information in form fields
// Examples: ask for extra fields (credit card number), display extra information
    function selection() {
      return array('id' => $this->code,
                   'module' => $this->title);

    }

////
// Pre confirmation checks (ie, check if credit card information is right before sending the info to
// the payment server
    function pre_confirmation_check() {
      return false;
    }


////
// !Functions to execute before displaying the checkout confirmation page
// Note: Set the variable $checkout_form_action to set the form action value
// Examples: validate (server-side with PHP) extra fields, redirect to online payment services (eg, PayPal)
    function confirmation() {
        return false;
    }

////
// !Functions to execute before finishing the form
// Examples: add extra hidden fields to the form
    function process_button() {
      global $order, $db;

      // basic info
      $AMT = str_replace(",",".",number_format($order->info['total'], 2));
      $variab = $_SESSION['customer_id'];
      $variab .= date ("dmy");
      $sign = $this->send_sign($AMT, $variab);

      // draw the required hidden fields
      $process_button_string = zen_draw_hidden_field('pu_predcislo', MODULE_PAYMENT_SPOROPAY_PU_PREDCISLO).      
                               zen_draw_hidden_field('pu_cislo', MODULE_PAYMENT_SPOROPAY_PU_CISLO).    
                               zen_draw_hidden_field('pu_kbanky', MODULE_PAYMENT_SPOROPAY_PU_KBANKY).      
                               zen_draw_hidden_field('suma', $AMT).
                               zen_draw_hidden_field('mena', MODULE_PAYMENT_SPOROPAY_CUR).      
                               zen_draw_hidden_field('vs', $variab).      
                               zen_draw_hidden_field('ss', '').
                               zen_draw_hidden_field('url', $this->get_url()).      
                               zen_draw_hidden_field('param', $this->get_param());      
                               zen_draw_hidden_field('sign1', $sign);      

      return $process_button_string;
    }


////
// !Functions to execute before processing the order
// Examples: retreive result from online payment services
    function before_process() {
      global $order;

      // get amount from order rather than from result
      $AMT = str_replace(",",".",number_format($order->info['total'], 2));
      $sign2 = $this->receive_sign ($_GET['u_predcislo'], $_GET['u_cislo'], $_GET['u_kbanky'], $AMT, $_GET['vs']);
      
      if ((($_GET['result'] != 'OK') and ($_GET['real'] != 'OUT')) or strcasecmp($sign2, $_GET['SIGN2']) != '0') {
          zen_redirect(zen_href_link(FILENAME_CHECKOUT_PAYMENT, 'error_message=' . urlencode(MODULE_PAYMENT_SPOROPAY_TEXT_ERROR_MESSAGE), 'SSL', true, false));
      }

      return false;
    }


////
// !Functions to execute after processing the order
// Examples: email part of the credit card number
    function after_process() {
// insert code here
      return false;
    }

////
// !If an error occurs with the process, output error messages here
    function output_error() {
      return false;
    }



////
// !Check if module is installed (Administration Tool)_
// TABLES: configuration
    function check() {
      global $db;
      if (!isset($this->check)) {
        $check_query = $db->Execute("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_STATUS'");
        $this->check = $check_query->RecordCount();
      }
      return $this->check;
    }


////
// !Install the module (Administration Tool)_
// TABLES: configuration
    function install() {
      global $db;
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Allow SporoPay Payments', 'MODULE_PAYMENT_SPOROPAY_STATUS', '1', 'Do you want to accept SporoPay payments?', '6', '6', now())");

      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('SporoPay PIN', 'MODULE_PAYMENT_SPOROPAY_PIN', '1234567890123456', 'PIN obchodnka.', '6', '3', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Predslo .', 'MODULE_PAYMENT_SPOROPAY_PU_PREDCISLO', '123456', 'Predslo tu.', '6', '3', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('..', 'MODULE_PAYMENT_SPOROPAY_PU_CISLO', '1234567890', 'slo tu.', '6', '3', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Banka', 'MODULE_PAYMENT_SPOROPAY_PU_KBANKY', '0900', 'Kd banky.', '6', '3', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Mena', 'MODULE_PAYMENT_SPOROPAY_CUR', 'EUR', 'Mena.', '6', '3', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('S.s.', 'MODULE_PAYMENT_SPOROPAY_SS', '', 'pecifick symbol.', '6', '3', now())");
      
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Poradie zobrazenia', 'MODULE_PAYMENT_SPOROPAY_SORT_ORDER', '0', 'Poradie zobrazenia. Najniie slo je zobrazen ako prv.', '6', '2', now())");
    }

////
// !Remove the module (Administration Tool)_
// TABLES: configuration
    function remove() {
      global $db;
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_STATUS'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_PIN'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_PU_PREDCISLO'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_PU_CISLO'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_PU_KBANKY'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_CUR'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_SS'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_SPOROPAY_SORT_ORDER'");
    }

////
// !Retreive the modules configuration keys (Administration Tool)_
    function keys() {
      $keys = array('MODULE_PAYMENT_SPOROPAY_STATUS', 'MODULE_PAYMENT_SPOROPAY_PIN', 'MODULE_PAYMENT_SPOROPAY_PU_PREDCISLO', 'MODULE_PAYMENT_SPOROPAY_PU_CISLO', 'MODULE_PAYMENT_SPOROPAY_SS', 'MODULE_PAYMENT_SPOROPAY_CUR', 'MODULE_PAYMENT_SPOROPAY_PU_KBANKY', 'MODULE_PAYMENT_SPOROPAY_SORT_ORDER');

      return $keys;
    }
  }
?>
