<?php
/*
Copyright (c) 2002 Jindrich Kratochvil <jindrich@mbox.vol.cz>, all rights
reserved. Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  1.Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  2.Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
  3.The name of the author may not be used to endorse or promote products
    derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */

require_once 'includes/configure.php';

  class TatraPay extends base{
    var $code, $title, $description, $enabled;

////
// !Class constructor -> initialize class variables.
// Sets the class code, description, and status.
    function TatraPay() {
      $this->code = 'TatraPay';
      $this->title = MODULE_PAYMENT_TATRAPAY_TEXT_TITLE;
      $this->description = MODULE_PAYMENT_TATRAPAY_TEXT_DESCRIPTION;
      $this->email_footer = MODULE_PAYMENT_TATRAPAY_TEXT_EMAIL_FOOTER;
      $this->enabled = MODULE_PAYMENT_TATRAPAY_STATUS;
      $this->sort_order = MODULE_PAYMENT_TATRAPAY_SORT_ORDER;

      $this->form_action_url = 'https://moja.tatrabanka.sk/cgi-bin/e-commerce/start/e-commerce.jsp';
    }

////
// Create signature
    function make_sign( $value, $key) {

        // get the SHA1
        $hash = substr(mhash (MHASH_SHA1, $value), 0, 8);
        // encrypt hash with key
        if (function_exists('mcrypt_module_open')) {         // We have mcrypt 2.4.x
            $td = mcrypt_module_open(MCRYPT_TripleDES, "", MCRYPT_MODE_ECB, "");
            $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size ($td), MCRYPT_RAND);
            mcrypt_generic_init($td, $key, $iv);
            $signature = strtoupper(bin2hex(mcrypt_generic ($td, $hash)));
            mcrypt_generic_end ($td);
        } else {                        // We have 2.2.x only
            $signature = strtoupper(bin2hex(mcrypt_ecb (MCRYPT_3DES, $key, $hash, MCRYPT_ENCRYPT)));
        }

        return $signature;
    }

////
// Get url
    function get_url() {
        if (ENABLE_SSL_ADMIN == 'true') {
          $link = HTTPS_SERVER . DIR_WS_HTTPS_CATALOG . 'redirect_to_payment.php';
        } else {
          $link = HTTP_SERVER . DIR_WS_CATALOG . 'redirect_to_payment.php';
        }
        
        return $link;
    }
    
////
// Calculate send sign
    function send_sign ($AMT, $variab) {
        $RURL = zen_href_link(FILENAME_CHECKOUT_PROCESS,"", 'SSL');
        return $this->make_sign (MODULE_PAYMENT_TATRAPAY_MID.$AMT.$variab.
                                 MODULE_PAYMENT_TATRAPAY_CS.$RURL,
                                 MODULE_PAYMENT_TATRAPAY_MIK);
    }

////
// Calculate send sign
    function receive_sign ($vs, $res) {
        return $this->make_sign ($vs.$res,
                                 MODULE_PAYMENT_TATRAPAY_MIK);
    }

////
// !Javascript form validation
// Check the user input submited on checkout_payment.php with javascript (client-side).
// Examples: validate credit card number, make sure required fields are filled in
    function javascript_validation() {
// insert code here
    }

////
// !Form fields for user input
// Output any required information in form fields
// Examples: ask for extra fields (credit card number), display extra information
    function selection() {
      return array('id' => $this->code,
                   'module' => $this->title);

    }

////
// Pre confirmation checks (ie, check if credit card information is right before sending the info to
// the payment server
    function pre_confirmation_check() {
      return false;
    }


////
// !Functions to execute before displaying the checkout confirmation page
// Note: Set the variable $checkout_form_action to set the form action value
// Examples: validate (server-side with PHP) extra fields, redirect to online payment services (eg, PayPal)
    function confirmation() {
        return false;
    }

////
// !Functions to execute before finishing the form
// Examples: add extra hidden fields to the form
    function process_button() {
// insert code here
      global $order, $db;

      $AMT = str_replace(",","",number_format($order->info['total'], 2));
      $variab = $_SESSION['customer_id'];
      $variab .= date ("dmy");
      $sign = $this->send_sign($AMT, $variab);
      if ($_POST[comments] != '') $this->DESC = zen_draw_hidden_field('DESC', $_POST[comments]);
      if (MODULE_PAYMENT_TATRAPAY_RSMS != '') $this->RSMS = zen_draw_hidden_field('RSMS', MODULE_PAYMENT_TATRAPAY_RSMS);
      if (MODULE_PAYMENT_TATRAPAY_REM != '') $this->REM = zen_draw_hidden_field('REM', MODULE_PAYMENT_TATRAPAY_REM);

      $process_button_string = zen_draw_hidden_field('PT', "TatraPay") .
                               zen_draw_hidden_field('MID', MODULE_PAYMENT_TATRAPAY_MID) .
                               zen_draw_hidden_field('AMT', $AMT) .
                               zen_draw_hidden_field('VS', $variab) .
                               zen_draw_hidden_field('CS', MODULE_PAYMENT_TATRAPAY_CS) .
                               zen_draw_hidden_field('RURL', $this->get_url()).
                               $this->DESC .
                               $this->RSMS .
                               $this->REM  .
                               zen_draw_hidden_field('SIGN', $sign);
      return $process_button_string;
    }


////
// !Functions to execute before processing the order
// Examples: retreive result from online payment services
    function before_process() {
      $csign = $this->receive_sign ($_GET['VS'].$_GET['RES']);
      if((($_GET['RES'] != 'OK') and ($_GET['RES'] != 'TOUT')) or strcasecmp($csign, $_GET['SIGN']) != '0'){
          zen_redirect(zen_href_link(FILENAME_CHECKOUT_PAYMENT, 'error_message=' . urlencode(MODULE_PAYMENT_TATRAPAY_TEXT_ERROR_MESSAGE), 'SSL', true, false));
      }
      return false;
    }


////
// !Functions to execute after processing the order
// Examples: email part of the credit card number
    function after_process() {
// insert code here
      return false;
    }

////
// !If an error occurs with the process, output error messages here
    function output_error() {
      return false;
    }



////
// !Check if module is installed (Administration Tool)_
// TABLES: configuration
    function check() {
      global $db;
      if (!isset($this->check)) {
        $check_query = $db->Execute("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_STATUS'");
        $this->check = $check_query->RecordCount();
      }
      return $this->check;
    }


////
// !Install the module (Administration Tool)_
// TABLES: configuration
    function install() {
      global $db;
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Allow TatraPay Payments', 'MODULE_PAYMENT_TATRAPAY_STATUS', '1', 'Do you want to accept TatraPay payments?', '6', '6', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('MID', 'MODULE_PAYMENT_TATRAPAY_MID', '001', 'ID obchodnka.', '6', '3', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('MIK', 'MODULE_PAYMENT_TATRAPAY_MIK', 'testep01', 'K obchodnka.', '6', '2', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('CS', 'MODULE_PAYMENT_TATRAPAY_CS', '308', 'Kontantn Symbol.', '6', '2', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('RSMS', 'MODULE_PAYMENT_TATRAPAY_RSMS', '', 'Reply SMS.', '6', '2', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('REM', 'MODULE_PAYMENT_TATRAPAY_REM', '', 'Reply Email.', '6', '2', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Poradie zobrazenia', 'MODULE_PAYMENT_TATRAPAY_SORT_ORDER', '0', 'Poradie zobrazenia. Najniie slo je zobrazen ako prv.', '6', '2', now())");
    }

////
// !Remove the module (Administration Tool)_
// TABLES: configuration
    function remove() {
      global $db;
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_STATUS'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_MID'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_MIK'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_CS'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_RSMS'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_REM'");
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_TATRAPAY_SORT_ORDER'");
    }

////
// !Retreive the modules configuration keys (Administration Tool)_
// Check the user input submited on checkout_payment.php with javascript (client-side).
    function keys() {
      $keys = array('MODULE_PAYMENT_TATRAPAY_MID', 'MODULE_PAYMENT_TATRAPAY_MIK', 'MODULE_PAYMENT_TATRAPAY_CS', 'MODULE_PAYMENT_TATRAPAY_RSMS', 'MODULE_PAYMENT_TATRAPAY_REM', 'MODULE_PAYMENT_TATRAPAY_SORT_ORDER');

      return $keys;
    }
  }
?>
